Оценка композиций
Пред. | Глава 5. Использование | След.

## Оценка композиций

Оценивать композиции может любой слушатель, имеющий аккаунт в сети Jabber. Для этого по мере прослушивания эфира следует отправлять специальному роботу команды rocks, если композиция нравится, или sucks, если не нравится. Все голоса записываются и влияют на рейтинг.

Чтобы проголосовать за композицию, которая сейчас не звучит (например, если вы опоздали), можно указать её идентификатор:

    rocks 1234

Пред. | Наверх | След.
Глава 5. Использование | Начало | Получение статистики